#! /bin/sh
#
# Using the ads1115 appliction, reads the voltages and checks if they are 
# within range. The configuration file is in the format of:
#
# I2C_Bus
# I2C_Address
# low_value_ain0,high_value_ain0
# low_value_ain1,high_value_ain1
# low_value_ain2,high_value_ain2
# low_value_ain3,high_value_ain3
#
# $1 - File to read the configuration of.

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"
rv=0
#
# check_value - check an individual A/D port value
# $1 Name
# $2 Value
# $3 Min
# $4 Max
# returns 0 on success

check_value() {

local rv=0
local name=$1
local ain=$2
local minval=$3
local maxval=$4

echo "$name: val=$ain [ $minval -- $maxval ]"
if [ `echo "$ain < $minval" | bc` -ne 0 ] || [ `echo "$ain > $maxval" | bc` -ne 0 ]
then
	partial_fail "Value out of range for $name"
	rv=-1
fi
return $rv
}

cnt=0
while IFS='' read -r line || [[ -n "$line" ]]; do

	low=`echo $line | awk '{split($1,a,","); print a[1]}'`
	high=`echo $line | awk '{split($1,a,","); print a[2]}'`

	case $cnt in
		0)
			bus=$line
			;;
		1)
			addr=$line
			;;
		2)
			low0=$low
			high0=$high
			;;
		3)
			low1=$low
			high1=$high
			;;
		4)
			low2=$low
			high2=$high
			;;
		5)
			low3=$low
			high3=$high
			;;
	esac
	cnt=$((cnt+1))
done < "$1"

values=`ads1115 -1 1 -2 1 -3 1 -4 1 -a $addr -b $bus dump 2>&1`

# Check that "values" is real since the ADC might not have been found.
if ( echo $values | grep -q "unable to read voltage" )
then
	fail_out "Could not find ADC at addr " ${bus}:${addr}
fi 

ain0=`echo $values | awk '{print $6}'`
ain1=`echo $values | awk '{print $12}'`
ain2=`echo $values | awk '{print $18}'`
ain3=`echo $values | awk '{print $24}'`

check_value AIN0 $ain0 $low0 $high0 || rv=$(( rv-1 ))
check_value AIN1 $ain1 $low1 $high1 || rv=$(( rv-1 ))
check_value AIN2 $ain2 $low2 $high2 || rv=$(( rv-1 ))
check_value AIN3 $ain3 $low3 $high3 || rv=$(( rv-1 ))

exit $rv
