#! /bin/sh

script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

success=""

TYPE="Fan test:"
OUT1=/tmp/fan_off
OUT2=/tmp/fan_on

function result()
{
	echo $1 | tee -a $2
}

check_off()
{
	if [ `echo "$1 != 0" | bc` -ne 0 ]
	then
		result "$2: FAIL" $3
	else
		result "$2: PASS" $3
	fi
}

check_on()
{
	if [ `echo "$1 < $2" | bc` -ne 0 ]
	then
		result "$4: FAIL" $5
	elif [ `echo "$1 > $3" | bc` -ne 0 ]
	then
		result "$4: FAIL" $5
	else
		result "$4: PASS" $5
	fi

}

cnt=0
while IFS='' read -r line || [[ -n "$line" ]]; do

	low=`echo $line | awk '{split($1,a,","); print a[1]}'`
	high=`echo $line | awk '{split($1,a,","); print a[2]}'`

	case $cnt in
		0)
			addr=$line
			;;
		1)
			low0=$low
			high0=$high
			;;
		2)
			low1=$low
			high1=$high
			;;
	esac
	cnt=$((cnt+1))
done < "$1"

fan_test -a $addr -d $low0 > /dev/null
sleep 3
off=`fan_test -a $addr`

fan1_rpm_off=`echo $off | cut -d: -f2 | awk '{print $1}'`
fan2_rpm_off=`echo $off | cut -d: -f4 | awk '{print $1}'`

check_off $fan1_rpm_off "Fan 1 off" $OUT1
check_off $fan2_rpm_off "Fan 2 off" $OUT1

fan_test -a $addr -d $high0 > /dev/null
sleep 3
on=`fan_test -a $addr`

fan1_rpm_on=`echo $on | cut -d: -f2 | awk '{print $1}'`
fan2_rpm_on=`echo $on | cut -d: -f4 | awk '{print $1}'`

check_on $fan1_rpm_on $low1 $high1 "Fan 1 on" $OUT2
check_on $fan2_rpm_on $low1 $high1 "Fan 2 on" $OUT2

if ( grep -q "FAIL" $OUT1 ); then
	SUMMARY="Fan Off: FAILED"
	partial_fail "ERR210-1 Fans not off when they should be: $fan1_rpm_off $fan2_rpm_off"
else
	SUMMARY="Fan Off: PASSED"
fi

if ( grep -q "FAIL" $OUT2 ); then
	SUMMARY="$SUMMARY Fan On: FAILED"
	partial_fail "ERR210-1 Fans not on or out of range RPM reading: $fan1_rpm_on $fan2_rpm_on"
else
	SUMMARY="$SUMMARY Fan On: PASSED"
fi

printf %-30s "$TYPE" | tee -a $RESULTS
echo "$SUMMARY" | tee -a $RESULTS

rm -f $OUT1 $OUT2
