#!/bin/sh

script_dir=$(dirname $0)
source ${script_dir}/error_codes.sh

# locals
TYPE="HWMON test:"
result="PASSED"

tmin=10000
tmax=50000
#
# check_temp checks that the passed in temp value is in range
# params:
# $1 temperature in milli-degrees
# return 0 in success
#        1 if temp low
#        2 if temp hi
#
check_temp() {
	local t=$1
	local rv=0
	if (( $t < $tmin ))
	then
		partial_fail Temperature $t below min $tmin
		rv=1
	elif (( $t > $tmax ))
	then
		partial_fail Temperature $t above max $tmax
		rv=2
	fi
	return $rv
}

HWMON_DIR=/sys/class/hwmon/
for hwmon in $HWMON_DIR/hwmon*
do
	for ii in $hwmon/temp[0-9]_input
	do
		temp=$(cat ${ii})
		if echo "$temp" | grep -qs '^[0-9][0-9][0-9][0-9][0-9]$'
		then
			check_temp $temp || result="FAILED"
			tc=$(echo "scale=3;${temp} / 1000.0" | bc -l)
			echo "$TYPE" $(basename $ii) ${tc} deg C| tee -a $RESULTS
		else
			result="FAILED"
			partial_fail ${TYPE} $(basename $ii) Error reading temperature - ${temp}
		fi
	done
done
# Print results to summary
printf "%-30s" "$TYPE" | tee -a $RESULTS
echo $result | tee -a $RESULTS
