#!/bin/sh
script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

# locals
TYPE="Power Supply Test:"
CHECK_PHRASE="Value out of range"
CHECK_PHRASE2="Could not find ADC"
OUT0="/tmp/ps1_test_tmp"
OUT1="/tmp/ps2_test_tmp"
OUT2="/tmp/io_test_tmp"

export BANK_VOLTAGE_NUM="unknown"

bank_voltage

partnum=$BANK_VOLTAGE_NUM

echo "Using ${partnum} for power"

sens_pwr2_file=${script_dir}/sens_power2_${partnum}
# A10 board uses GPIO 447
${script_dir}/set_gpio.sh

${script_dir}/check_voltage.sh ${script_dir}/io_power | tee -a $OUT2

${script_dir}/check_voltage.sh ${script_dir}/sens_power1 | tee -a $OUT0

if [ ! -e "${sens_pwr2_file}" ]; then
	echo "Could not find ADC configuration file ${sens_pwr2_file}. Is factory config set properly?" | tee -a $OUT1
else
	${script_dir}/check_voltage.sh ${sens_pwr2_file} | tee -a $OUT1
fi

rc="PASS"
if ( grep -q "$CHECK_PHRASE2" $OUT0 ) || ( grep -q "$CHECK_PHRASE2" $OUT1 ) || ( grep -q "$CHECK_PHRASE2" $OUT2 ); then
	partial_fail "ERR61-1 I2C1 bus error"
	rc="FAIL"
fi

if ( grep -q "$CHECK_PHRASE" $OUT2 ); then
	partial_fail "ERR120-1 IO Board power supply error"
	rc="FAIL"
fi

if ( grep -q "$CHECK_PHRASE" $OUT0 ); then
	partial_fail "ERR120-2 Sensor board power supply error"
	rc="FAIL"
fi

if ( grep -q "$CHECK_PHRASE" $OUT1 ); then
	partial_fail "ERR120-3 SOM-Specific power supply issue"
	rc="FAIL"
fi

echo
printf %-30s "$TYPE" | tee -a $RESULTS
if [[ "$rc" == "FAIL" ]]; then
	echo "FAILED" | tee -a $RESULTS
else
	echo "PASSED" | tee -a $RESULTS
fi

# Clean up
rm $OUT0 $OUT1 $OUT2

