#!/bin/sh
script_dir=$(dirname $0)
source "$script_dir/error_codes.sh"

# locals
TYPE="Clock test:"
SERVER=10.0.0.112
result="UNKNOWN"
T1=""; T1_CUT=""; T2=""; T2_CUT="";
T_LEN=42

echo "Setting date/time"
rdate $SERVER
hwclock -w
echo "Waiting 3 seconds"
sleep 3

echo "Checking time"
T1=`hwclock`
if [ -z "$T1" ]; then
	# Try again
	T1=`hwclock`
fi
T1_CUT=`echo $T1 | awk -F " " '{print $3$4}' | sed "s/://g"`

echo $T1
echo "Waiting 3 seconds"
sleep 3

echo "Checking time again"
T2=`hwclock`
if [ -z "$T2" ]; then
	# Try again
	T2=`hwclock`
fi
T2_CUT=`echo $T2 | awk -F " " '{print $3$4}' | sed "s/://g"`
echo $T2

echo "Comparing"
if [ -z "$T1" -o -z "$T2" ]; then
	# T1 or T2 is empty, hwclock failed
	echo "ERROR: One or both times are unwritten"
	echo "Please try running ${script_dir}/rtc_test.sh again"
	result="FAILED"
elif [ ${#T1} -ne $T_LEN -o ${#T2} -ne $T_LEN ]; then
	# Time sting lengths aren't default, assume failure
	echo "ERROR: Length of time strings incorrect, assume failure"
	result="FAILED"
elif [ "$T1" = "$T2" ]; then
	# Times are the same, failure
	echo "ERROR: Time did not change"
	result="FAILED"
elif [ $T2_CUT -gt $T1_CUT ]; then
	# RTC was written and has incremented, pass
	result="PASSED"
else
	# Time has reversed (test run at midnight?) or something unexpected occurred...
	result="UNKNOWN"
fi

if [ "$result" != "PASSED" ]; then
	partial_fail "ERR60-2 Error setting/reading RTC"
fi

#Print results to summary
printf "%-30s" "$TYPE" | tee -a $RESULTS
echo "$result: Time = $T2" | tee -a $RESULTS
